@@ -63,15 +63,12 @@
 #include <KActionCollection>
 #include <KDebug>
 #include <KFileDialog>
-#include <KFind>
-#include <KFindDialog>
 #include <KIcon>
 #include <KInputDialog>
 #include <KLineEdit>
 #include <KLocale>
 #include <KMenu>
 #include <KMessageBox>
-#include <KMimeType>
 #include <KMimeTypeTrader>
 #include <KProcess>
 #include <KRecentFilesAction>
@@ -80,22 +77,17 @@
 #include <KService>
 #include <KShortcut>
 #include <KStandardAction>
-#include <KStandardDirs>
+#include <KStandardGuiItem>
 #include <KStandardShortcut>
 #include <KStatusBar>
 #include <KStatusNotifierItem>
 #include <KToggleAction>
-#include <KToolBar>
 #include <KToolInvocation>
-#include <KUniqueApplication>
 #include <KUrl>
-#include <KVBox>
 #include <QApplication>
 #include <QClipboard>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QEvent>
-#include <QFile>
 #include <QKeySequence>
 #include <QLabel>
 #include <QList>
@@ -104,9 +96,8 @@
 #include <QPrintDialog>
 #include <QPrinter>
 #include <QProcess>
-#include <QTextStream>
 #include <QWidget>
-#include <QtDBus/QtDBus>
+#include <QDBusConnection>
 #include <kabc/addresseelist.h>
 // #include <kabc/key.h> TODO
 #include <kio/global.h>
@@ -592,7 +583,7 @@ void KeysManager::slotGenerateKeyDone(KJob *job)
 		updateStatusCounter();
 
 		QPointer<KDialog> keyCreated = new KDialog(this);
-		keyCreated->setCaption(i18n("New Key Pair Created"));
+		keyCreated->setWindowTitle(i18n("New Key Pair Created"));
 		keyCreated->setButtons(KDialog::Ok);
 		keyCreated->setDefaultButton(KDialog::Ok);
 		keyCreated->setModal(true);
@@ -887,7 +878,7 @@ void KeysManager::slotAddUid()
 	}
 
 	addUidWidget = new KDialog(this );
-	addUidWidget->setCaption( i18n("Add New User Id") );
+	addUidWidget->setWindowTitle(i18n("Add New User Id"));
 	addUidWidget->setButtons(  KDialog::Ok | KDialog::Cancel );
 	addUidWidget->setDefaultButton(  KDialog::Ok );
 	addUidWidget->setModal( true );
@@ -1769,7 +1760,7 @@ void KeysManager::editGroup()
 		return;
 	KGpgGroupNode *gnd = nd->toGroupNode();
 	QPointer<KDialog> dialogGroupEdit = new KDialog(this );
-	dialogGroupEdit->setCaption( i18n("Group Properties") );
+	dialogGroupEdit->setWindowTitle(i18n("Group Properties"));
 	dialogGroupEdit->setButtons( KDialog::Ok | KDialog::Cancel );
 	dialogGroupEdit->setDefaultButton(  KDialog::Ok );
 	dialogGroupEdit->setModal( true );
@@ -2531,7 +2522,7 @@ void KeysManager::slotDelKeyDone(int res)
 void KeysManager::slotPreImportKey()
 {
 	QPointer<KDialog> dial = new KDialog(this);
-	dial->setCaption(i18n("Key Import"));
+	dial->setWindowTitle(i18n("Key Import"));
 	dial->setButtons(KDialog::Ok | KDialog::Cancel);
 	dial->setDefaultButton(KDialog::Ok);
 	dial->setModal(true);
@@ -2857,5 +2848,3 @@ KeysManager::clipSign()
 	kgpgtxtedit->m_editor->signVerifyText(cliptext);
 	kgpgtxtedit->show();
 }
-
-#include "keysmanager.moc"
