@@ -25,11 +25,9 @@
 class KeysManager;
 class KGpgFirstAssistant;
 class KGpgItemModel;
-class KGpgTextInterface;
 class KJob;
 class KShortcut;
 class KTemporaryFile;
-class QFont;
 class QString;
 
 /**
@@ -48,23 +46,23 @@ public:
 
 	void showDroppedFile(const KUrl &file);
 	void verifyFile(KUrl url);
-	/**
-	 * @brief create a detached signature for a chosen files
-	 */
-	void signDroppedFiles(const KUrl::List &urls);
-	void decryptDroppedFiles(const KUrl::List &urls);
-	void encryptDroppedFolders(const KUrl::List &urls);
 
+	/**
+	 * @brief create a detached signature for the given files
+	 */
+	static void signFiles(KeysManager* parent, const KUrl::List &urls);
+
+	static void decryptFiles(KeysManager* parent, const KUrl::List& urls);
+	static void encryptFolders(KeysManager* parent, const KUrl::List &urls);
+
+	/**
+	 * @brief create a new object, encrypt the given files, and destroy the object
+	 */
+	static void encryptFiles(KeysManager* parent, const KUrl::List& urls);
 signals:
 	void createNewKey();
 	void updateDefault(QString);
 
-public slots:
-	void slotEncryptDroppedFiles(const KUrl::List &urls);
-
-	void startFolderEncode();
-	void slotAbortEnc();
-
 private:
 	QStringList customDecrypt;
 	QPointer<KGpgFirstAssistant> m_assistant;
@@ -84,6 +82,7 @@ private:
 	void decryptFile(KUrl::List urls);
 
 private slots:
+	void startFolderEncode();
 	void slotSaveOptionsPath();
 	void slotVerificationDone(int result);
 	void help();
@@ -91,7 +90,6 @@ private slots:
 	void slotSetCompression(int cp);
 	void slotDecryptionDone(int status);
 	void slotFolderFinished(KJob *job);
-	void slotSigningFinished();
 	void slotSignFiles();
 	void slotEncryptionKeySelected();
 };
