@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2006,2007,2008,2009,2010,2011,2012,2013,2014
+ * Copyright (C) 2006,2007,2008,2009,2010,2011,2012,2013,2014,2015
  *               Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 /***************************************************************************
@@ -31,11 +31,12 @@
 #include <KMessageBox>
 #include <KProcess>
 #include <KStandardDirs>
+#include <KDebug>
+#include <KUrl>
 #include <QCheckBox>
 #include <QFile>
 #include <QTextStream>
 #include <QVBoxLayout>
-#include <kdefakes.h>
 
 using namespace KgpgCore;
 
@@ -62,11 +63,12 @@ kgpgOptions::kgpgOptions(QWidget *parent, KGpgItemModel *model)
 	m_combomodel->sort(0);
 
 	// Initialize the default server and the default server list.
-	defaultKeyServer = QLatin1String("hkp://wwwkeys.pgp.net");
+	defaultKeyServer = QLatin1String("hkp://pool.sks-keyservers.net");
 	defaultServerList << defaultKeyServer
+			<< QLatin1String("hkp://subkeys.pgp.net")
 			<< QLatin1String("hkp://search.keyserver.net")
 			<< QLatin1String("hkp://pgp.dtype.org")
-			<< QLatin1String("hkp://subkeys.pgp.net");
+			<< QLatin1String("hkp://wwwkeys.pgp.net");
 
 	// Read the default keyserver from the GnuPG settings.
 	keyServer = KgpgInterface::getGpgSetting(QLatin1String( "keyserver" ), KGpgSettings::gpgConfigPath());
@@ -300,7 +302,7 @@ void kgpgOptions::updateWidgets()
 
 				KGpgKeyNode *anode = m_combomodel->getModel()->findKeyNode(fileId);
 
-				if (anode != NULL)
+				if (anode != Q_NULLPTR)
 					idpos = m_combomodel->nodeIndex(anode).row();
 			}
 		}
@@ -309,7 +311,7 @@ void kgpgOptions::updateWidgets()
 
 	if (!alwaysKeyID.isEmpty()) {
 		KGpgKeyNode *anode = m_combomodel->getModel()->findKeyNode(alwaysKeyID);
-		if (anode != NULL) {
+		if (anode != Q_NULLPTR) {
 			const QModelIndex midx(m_combomodel->nodeIndex(anode));
 			m_page1->always_key->setCurrentIndex(midx.row());
 		}
@@ -469,9 +471,9 @@ void kgpgOptions::listKeys()
 	if (m_model->rowCount(QModelIndex()) == 0) {
 		ids += QLatin1String("0");
 		m_page1->file_key->addItem(i18nc("no key available", "none"));
-		m_page1->file_key->setModel(NULL);
+		m_page1->file_key->setModel(Q_NULLPTR);
 		m_page1->always_key->addItem(i18nc("no key available", "none"));
-		m_page1->always_key->setModel(NULL);
+		m_page1->always_key->setModel(Q_NULLPTR);
 	} else {
 		m_page1->file_key->setModel(m_combomodel);
 		m_page1->always_key->setModel(m_combomodel);
@@ -604,5 +606,3 @@ void kgpgOptions::slotSystrayEnable()
 {
 	m_page7->kcfg_LeftClick->setEnabled(m_page7->kcfg_ShowSystray->isChecked());
 }
-
-#include "kgpgoptions.moc"
