@@ -20,12 +20,14 @@
 
 #include "ui_sourceselect.h"
 
+#include <kgpgcompiler.h>
+
 class SrcSelect : public QWidget, public Ui::SrcSelect
 {
 	Q_OBJECT
 
 public:
-	explicit SrcSelect(QWidget *parent = 0);
+	explicit SrcSelect(QWidget *parent = Q_NULLPTR);
 
 private slots:
 	void checkFile_toggled(bool isOn);
